@@ -35,7 +35,7 @@
  *
  * prototypes of libmisc functions, and private lib functions.
  *
- * $Id: prototypes.h 2197 2008-06-26 20:28:31Z nekral-guest $
+ * $Id: prototypes.h 2450 2008-11-22 23:54:54Z nekral-guest $
  *
  */
 
@@ -73,7 +73,7 @@ extern char *Basename (char *str);
 extern int chown_tree (const char *, uid_t, uid_t, gid_t, gid_t);
 
 /* chowntty.c */
-extern void chown_tty (const char *, const struct passwd *);
+extern void chown_tty (const struct passwd *);
 
 /* console.c */
 extern int console (const char *);
