@@ -44,7 +44,7 @@
 #include <fcntl.h>
 #include <stdio.h>
 
-#ident "$Id: utmp.c 1980 2008-04-27 00:40:09Z nekral-guest $"
+#ident "$Id: utmp.c 2450 2008-11-22 23:54:54Z nekral-guest $"
 
 #if HAVE_UTMPX_H
 struct utmpx utxent;
@@ -56,6 +56,30 @@ struct utmp utent;
 #define	NO_TTY \
 	_("Unable to determine your tty name.")
 
+/*
+ * is_my_tty -- determine if "tty" is the same TTY stdin is using
+ */
+static int is_my_tty (const char *tty)
+{
+	char full_tty[200];
+	struct stat by_name, by_fd;
+
+	if ('/' != *tty) {
+		snprintf (full_tty, sizeof full_tty, "/dev/%s", tty);
+		tty = full_tty;
+	}
+
+	if ((stat (tty, &by_name) != 0) || (fstat (STDIN_FILENO, &by_fd) != 0)) {
+		return 0;
+	}
+
+	if (by_name.st_rdev != by_fd.st_rdev) {
+		return 0;
+	} else {
+		return 1;
+	}
+}
+
 /*
  * checkutmp - see if utmp file is correct for this process
  *
@@ -84,7 +108,8 @@ void checkutmp (int picky)
 	while ((ut = getutent ()))
 		if (ut->ut_pid == pid && ut->ut_line[0] && ut->ut_id[0] &&
 		    (ut->ut_type == LOGIN_PROCESS
-		     || ut->ut_type == USER_PROCESS))
+		     || ut->ut_type == USER_PROCESS) &&
+		    is_my_tty (ut->ut_line))
 			break;
 
 	/* If there is one, just use it, otherwise create a new one.  */
