@@ -32,7 +32,7 @@
 
 #include <config.h>
 
-#ident "$Id: login.c 2197 2008-06-26 20:28:31Z nekral-guest $"
+#ident "$Id: login.c 2450 2008-11-22 23:54:54Z nekral-guest $"
 
 #include <errno.h>
 #include <grp.h>
@@ -1005,7 +1005,7 @@ int main (int argc, char **argv)
 	}
 	setup_limits (&pwent);	/* nice, ulimit etc. */
 #endif				/* ! USE_PAM */
-	chown_tty (tty, &pwent);
+	chown_tty (&pwent);
 
 #ifdef USE_PAM
 	/*
