@@ -22,8 +22,8 @@
 #endif
 
 #ifndef USE_PAM
-#include "rcsid.h"
-RCSID ("$Id: login_nopam.c,v 1.5 2005/07/02 17:53:06 kloczek Exp $")
+#ident "$Id: login_nopam.c 1659 2008-01-06 12:07:42Z nekral-guest $"
+
 #include "prototypes.h"
     /*
      * This module implements a simple but effective form of login access
@@ -37,7 +37,9 @@ RCSID ("$Id: login_nopam.c,v 1.5 2005/07/02 17:53:06 kloczek Exp $")
 #include <stdio.h>
 #include <syslog.h>
 #include <ctype.h>
+#ifdef HAVE_NETDB_H
 #include <netdb.h>
+#endif
 #include <grp.h>
 #ifdef PRIMARY_GROUP_MATCH
 #include <pwd.h>
@@ -49,8 +51,6 @@ RCSID ("$Id: login_nopam.c,v 1.5 2005/07/02 17:53:06 kloczek Exp $")
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>		/* for inet_ntoa() */
-extern struct group *getgrnam ();
-extern int innetgr ();
 
 #if !defined(MAXHOSTNAMELEN) || (MAXHOSTNAMELEN < 64)
 #undef MAXHOSTNAMELEN
@@ -58,28 +58,25 @@ extern int innetgr ();
 #endif
 
  /* Path name of the access control file. */
-
 #ifndef	TABLE
 #define TABLE	"/etc/login.access"
 #endif
 
- /* Delimiters for fields and for lists of users, ttys or hosts. */
-
+/* Delimiters for fields and for lists of users, ttys or hosts. */
 static char fs[] = ":";		/* field separator */
 static char sep[] = ", \t";	/* list-element separator */
 
- /* Constants to be used in assignments only, not in comparisons... */
-
+/* Constants to be used in assignments only, not in comparisons... */
 #define YES             1
 #define NO              0
 
-static int list_match ();
-static int user_match ();
-static int from_match ();
-static int string_match ();
+static int list_match (char *list, const char *item, int (*match_fn) (const char *, const char *));
+static int user_match (const char *tok, const char *string);
+static int from_match (const char *tok, const char *string);
+static int string_match (const char *tok, const char *string);
+static const char *resolve_hostname (const char *string);
 
 /* login_access - match username/group and host/tty with access control file */
-
 int login_access (const char *user, const char *from)
 {
 	FILE *fp;
@@ -98,14 +95,13 @@ int login_access (const char *user, const char *from)
 	 * mandatory. The first field should be a "+" or "-" character. A
 	 * non-existing table means no access control.
 	 */
-
 	if ((fp = fopen (TABLE, "r"))) {
 		while (!match && fgets (line, sizeof (line), fp)) {
 			lineno++;
 			if (line[end = strlen (line) - 1] != '\n') {
 				SYSLOG ((LOG_ERR,
-					"%s: line %d: missing newline or line too long",
-					TABLE, lineno));
+					 "%s: line %d: missing newline or line too long",
+					 TABLE, lineno));
 				continue;
 			}
 			if (line[0] == '#')
@@ -120,14 +116,14 @@ int login_access (const char *user, const char *from)
 			    || !(froms = strtok ((char *) 0, fs))
 			    || strtok ((char *) 0, fs)) {
 				SYSLOG ((LOG_ERR,
-					"%s: line %d: bad field count",
-					TABLE, lineno));
+					 "%s: line %d: bad field count",
+					 TABLE, lineno));
 				continue;
 			}
 			if (perm[0] != '+' && perm[0] != '-') {
 				SYSLOG ((LOG_ERR,
-					"%s: line %d: bad first field",
-					TABLE, lineno));
+					 "%s: line %d: bad first field",
+					 TABLE, lineno));
 				continue;
 			}
 			match = (list_match (froms, from, from_match)
@@ -141,8 +137,7 @@ int login_access (const char *user, const char *from)
 }
 
 /* list_match - match an item against a list of tokens with exceptions */
-
-static int list_match (char *list, const char *item, int (*match_fn) ())
+static int list_match (char *list, const char *item, int (*match_fn) (const char *, const char*))
 {
 	char *tok;
 	int match = NO;
@@ -153,15 +148,14 @@ static int list_match (char *list, const char *item, int (*match_fn) ())
 	 * a match, look for an "EXCEPT" list and recurse to determine whether
 	 * the match is affected by any exceptions.
 	 */
-
 	for (tok = strtok (list, sep); tok != 0; tok = strtok ((char *) 0, sep)) {
 		if (strcasecmp (tok, "EXCEPT") == 0)	/* EXCEPT: give up */
 			break;
 		if ((match = (*match_fn) (tok, item)))	/* YES */
 			break;
 	}
-	/* Process exceptions to matches. */
 
+	/* Process exceptions to matches. */
 	if (match != NO) {
 		while ((tok = strtok ((char *) 0, sep))
 		       && strcasecmp (tok, "EXCEPT"))
@@ -173,7 +167,6 @@ static int list_match (char *list, const char *item, int (*match_fn) ())
 }
 
 /* myhostname - figure out local machine name */
-
 static char *myhostname (void)
 {
 	static char name[MAXHOSTNAMELEN + 1] = "";
@@ -185,8 +178,8 @@ static char *myhostname (void)
 	return (name);
 }
 
+#if HAVE_INNETGR
 /* netgroup_match - match group against machine or user */
-
 static int
 netgroup_match (const char *group, const char *machine, const char *user)
 {
@@ -201,9 +194,9 @@ netgroup_match (const char *group, const char *machine, const char *user)
 
 	return innetgr (group, machine, user, mydomain);
 }
+#endif
 
 /* user_match - match a username against one token */
-
 static int user_match (const char *tok, const char *string)
 {
 	struct group *group;
@@ -219,28 +212,31 @@ static int user_match (const char *tok, const char *string)
 	 * Otherwise, return YES if the token fully matches the username, or if
 	 * the token is a group that contains the username.
 	 */
-
 	if ((at = strchr (tok + 1, '@')) != 0) {	/* split user@host pattern */
 		*at = 0;
 		return (user_match (tok, string)
 			&& from_match (at + 1, myhostname ()));
+#if HAVE_INNETGR
 	} else if (tok[0] == '@') {	/* netgroup */
 		return (netgroup_match (tok + 1, (char *) 0, string));
+#endif
 	} else if (string_match (tok, string)) {	/* ALL or exact match */
 		return (YES);
+	/* local, no need for xgetgrnam */
 	} else if ((group = getgrnam (tok))) {	/* try group membership */
 		for (i = 0; group->gr_mem[i]; i++)
 			if (strcasecmp (string, group->gr_mem[i]) == 0)
 				return (YES);
 #ifdef PRIMARY_GROUP_MATCH
 		/*
-		 * If the sting is an user whose initial GID matches the token,
+		 * If the string is an user whose initial GID matches the token,
 		 * accept it. May avoid excessively long lines in /etc/group.
 		 * Radu-Adrian Feurdean <raf@licj.soroscj.ro>
 		 *
 		 * XXX - disabled by default for now.  Need to verify that
 		 * getpwnam() doesn't have some nasty side effects.  --marekm
 		 */
+		/* local, no need for xgetpwnam */
 		if ((userinf = getpwnam (string)))
 			if (userinf->pw_gid == group->gr_gid)
 				return (YES);
@@ -249,8 +245,7 @@ static int user_match (const char *tok, const char *string)
 	return (NO);
 }
 
-static char *resolve_hostname (string)
-char *string;
+static const char *resolve_hostname (const char *string)
 {
 	/*
 	 * Resolve hostname to numeric IP address, as suggested
@@ -281,10 +276,12 @@ static int from_match (const char *tok, const char *string)
 	 * contain a "." character. If the token is a network number, return YES
 	 * if it matches the head of the string.
 	 */
-
+#if HAVE_INNETGR
 	if (tok[0] == '@') {	/* netgroup */
 		return (netgroup_match (tok + 1, string, (char *) 0));
-	} else if (string_match (tok, string)) {	/* ALL or exact match */
+	} else
+#endif
+	if (string_match (tok, string)) {	/* ALL or exact match */
 		return (YES);
 	} else if (tok[0] == '.') {	/* domain: match last fields */
 		if ((str_len = strlen (string)) > (tok_len = strlen (tok))
@@ -301,7 +298,6 @@ static int from_match (const char *tok, const char *string)
 }
 
 /* string_match - match a string against one token */
-
 static int string_match (const char *tok, const char *string)
 {
 
@@ -309,7 +305,6 @@ static int string_match (const char *tok, const char *string)
 	 * If the token has the magic value "ALL" the match always succeeds.
 	 * Otherwise, return YES if the token fully matches the string.
 	 */
-
 	if (strcasecmp (tok, "ALL") == 0) {	/* all: always matches */
 		return (YES);
 	} else if (strcasecmp (tok, string) == 0) {	/* try exact match */
@@ -318,4 +313,6 @@ static int string_match (const char *tok, const char *string)
 	return (NO);
 }
 
+#else				/* !USE_PAM */
+extern int errno;		/* warning: ANSI C forbids an empty source file */
 #endif				/* !USE_PAM */
